<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

if (! class_exists('WP_Crowdfunding_Shortcode')) {

	class WP_Crowdfunding_Shortcode {

		/**
		 * @var null
		 *
		 * Instance of this class
		 */
		protected static $_instance = null;

		/**
		 * @return null|WP_Crowdfunding_Shortcode
		 */
		public static function instance() {
			if ( is_null( self::$_instance ) ) {
				self::$_instance = new self();
			}
			return self::$_instance;
		}

		public function __construct() {
			add_shortcode('wp_crowdfunding_single_campaign', array($this, 'wp_crowdfunding_single_campaign'));
			add_shortcode('wp_crowdfunding_campaign_box', array($this, 'wp_crowdfunding_campaign_box'));
		}

		/**
		 * @param $atts
		 * @param string $content
		 *
		 * @return string
		 *
		 * Single Campaign Details
		 */
		public function wp_crowdfunding_single_campaign( $atts, $content = "" ){
			$atts = shortcode_atts( array(
				'campaign_id' => 0,
			), $atts, 'wp_crowdfunding_single_campaign' );

			$args = array(
				'posts_per_page'      => 1,
				'post_type'           => 'product',
				'post_status'         => 'publish',
				'ignore_sticky_posts' => 1,
				'no_found_rows'       => 1,
			);

			if ( isset( $atts['campaign_id'] ) ) {
				$args['p'] = absint( $atts['campaign_id'] );
			}

			$single_product = new WP_Query( $args );

			// For "is_single" to always make load comments_template() for reviews.
			$single_product->is_single = true;

			ob_start();

			global $wp_query;

			// Backup query object so following loops think this is a product page.
			$previous_wp_query = $wp_query;
			$wp_query          = $single_product;

			wp_enqueue_script( 'wc-single-product' );

			while ( $single_product->have_posts() ) {
				$single_product->the_post();
				wpneo_crowdfunding_load_template('single-crowdfunding-content-only');
			}

			// restore $previous_wp_query and reset post data.
			$wp_query = $previous_wp_query;
			wp_reset_postdata();
			$final_content = ob_get_clean();

			return '<div class="woocommerce">' . $final_content . '</div>';
		}


		public function wp_crowdfunding_campaign_box( $atts, $content = "" ){
			$atts = shortcode_atts( array(
				'campaign_id' => 0,
			), $atts, 'wp_crowdfunding_campaign_box' );

			if ( !  $atts['campaign_id'] ){
				return false;
			}

			$args = array(
				'posts_per_page'      => 1,
				'post_type'           => 'product',
				'post_status'         => 'publish',
				'ignore_sticky_posts' => 1,
				'no_found_rows'       => 1,
			);

			if ( isset( $atts['campaign_id'] ) ) {
				$args['p'] = absint( $atts['campaign_id'] );
			}

			$single_product = new WP_Query( $args );

			// For "is_single" to always make load comments_template() for reviews.
			$single_product->is_single = true;

			ob_start();

			global $wp_query;

			// Backup query object so following loops think this is a product page.
			$previous_wp_query = $wp_query;
			$wp_query          = $single_product;

			while ( $single_product->have_posts() ) {
				$single_product->the_post();
				?>

				<div class="wpneo-listings three ">
					<?php do_action('wpneo_campaign_loop_item_before_content'); ?>
					<div class="wpneo-listing-content">
						<?php do_action('wpneo_campaign_loop_item_content'); ?>
					</div>
					<?php do_action('wpneo_campaign_loop_item_after_content'); ?>
				</div>
				<?php
			}
			// restore $previous_wp_query and reset post data.
			$wp_query = $previous_wp_query;
			wp_reset_postdata();
			$final_content = ob_get_clean();

			return $final_content;
		}


	}

	WP_Crowdfunding_Shortcode::instance();
	
}